@@ -2,18 +2,18 @@
 
 # BuildCompatible: KitCreator
 
-version="1.7.12"
+version="1.7.16"
 url="http://tcltls.rkeene.org/uv/tcltls-${version}.tar.gz"
-sha256='0e09e8e1cb3dcb3d419079fe40c521b7283d5e822dc914ffd1e4ff600b895caa'
+sha256='6845000732bedf764e78c234cee646f95bb68df34e590c39434ab8edd6f5b9af'
 configure_extra=('--enable-deterministic')
 
 function buildSSLLibrary() {
 	local version url hash
 	local archive
 
-	version='2.5.0'
+	version='2.6.4'
 	url="http://ftp.openbsd.org/pub/OpenBSD/LibreSSL/libressl-${version}.tar.gz"
-	hash='8652bf6b55ab51fb37b686a3f604a2643e0e8fde2c56e6a936027d12afda6eae'
+	hash='638a20c2f9e99ee283a841cd787ab4d846d1880e180c4e96904fc327d419d11f'
 
 	archive="src/libressl-${version}.tar.gz"
 
@@ -34,7 +34,7 @@ function buildSSLLibrary() {
 		CFLAGS=' -g -O0 '
 		export CFLAGS
 
-		./configure ${CONFIGUREEXTRA} --disable-shared --enable-static --prefix="$(pwd)/INST" || exit 1
+		./configure ${CONFIGUREEXTRA} --with-pic --disable-shared --enable-static --prefix="$(pwd)/INST" || exit 1
 
 		# Disable building the apps -- they do not get used
 		rm -rf apps
@@ -52,10 +52,7 @@ _EOF_
 	# We always statically link
 	KC_TLS_LINKSSLSTATIC='1'
 
-	SSLDIR="$(pwd)/libressl-${version}/INST"
-
-	PKG_CONFIG_PATH="${SSLDIR}/lib/pkgconfig:${PKG_CONFIG_PATH}"
-	export PKG_CONFIG_PATH
+	SSLPKGCONFIGDIR="$(pwd)/libressl-${version}/INST/lib/pkgconfig"
 
 	return 0
 }
@@ -66,20 +63,33 @@ function preconfigure() {
 		CPP="${CC:-cc} -E"
 	fi
 
+	SSLPKGCONFIGDIR=''
+	SSLDIR=''
+
 	if [ -n "${KC_TLS_SSLDIR}" ]; then
-		SSLDIR="${KC_TLS_SSLDIR}"
+		case "${KC_TLS_SSLDIR}" in
+			*/pkgconfig|*/pkgconfig/)
+				SSLPKGCONFIGDIR="${KC_TLS_SSLDIR}"
+				;;
+			*)
+				SSLDIR="${KC_TLS_SSLDIR}"
+				;;
+		esac
 	else
-		SSLDIR=''
-
+		SSLGUESS='0'
 		if [ -z "${KC_TLS_BUILDSSL}" ]; then
-			SSLDIR="$(echo '#include <openssl/ssl.h>' 2>/dev/null | ${CPP} - 2> /dev/null | awk '/# 1 "\/.*\/ssl\.h/{ print $3; exit }' | sed 's@^"@@;s@"$@@;s@/include/openssl/ssl\.h$@@')"
+			if ! "${PKG_CONFIG:-pkg-config}" --exists openssl >/dev/null 2>/dev/null; then
+				SSLDIR="$(echo '#include <openssl/ssl.h>' 2>/dev/null | ${CPP} - 2> /dev/null | awk '/# 1 "\/.*\/ssl\.h/{ print $3; exit }' | sed 's@^"@@;s@"$@@;s@/include/openssl/ssl\.h$@@')"
+			else
+				SSLGUESS='1'
+			fi
 		fi
 
-		if [ -z "${SSLDIR}" ]; then
-			buildSSLLibrary || SSLDIR=''
+		if [ -z "${SSLDIR}" -a "${SSLGUESS}" = '0' ]; then
+			buildSSLLibrary || SSLPKGCONFIGDIR=''
 		fi
 
-		if [ -z "${SSLDIR}" ]; then
+		if [ -z "${SSLPKGCONFIGDIR}" -a -z "${SSLDIR}" -a "${SSLGUESS}" = '0' ]; then
 			echo "Unable to find OpenSSL, aborting." >&2
 
 			return 1
@@ -87,7 +97,11 @@ function preconfigure() {
 	fi
 
 	# Add SSL library to configure options
-	configure_extra=("${configure_extra[@]}" --with-openssl-dir="${SSLDIR}")
+	if [ -n "${SSLPKGCONFIGDIR}" ]; then
+		configure_extra=("${configure_extra[@]}" --with-openssl-pkgconfig="${SSLPKGCONFIGDIR}")
+	elif [ -n "${SSLDIR}" ]; then
+		configure_extra=("${configure_extra[@]}" --with-openssl-dir="${SSLDIR}")
+	fi
 
 	# If we are statically linking to libssl, let tcltls know so it asks for the right
 	# packages
